==> boinc_7.8.3+dfsg.orig.tar.gz: boinc-client_release-7.8-7.8.3/README.md <==
# Status

[![Build Status](https://travis-ci.org/BOINC/boinc.svg?branch=master)](https://travis-ci.org/BOINC/boinc) [![Coverity Scan Build Status](https://scan.coverity.com/projects/4226/badge.svg)](https://scan.coverity.com/projects/boinc-boinc) [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/BOINC/boinc/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/BOINC/boinc/?branch=master)

# BOINC

Project Website: https://boinc.berkeley.edu

## Want to create a project
See: https://boinc.berkeley.edu/trac/wiki

## Want to help translate
See: https://boinc.berkeley.edu/trac/wiki/TranslateIntro

## Want to contribute
See: https://boinc.berkeley.edu/trac/wiki/SoftwareDevelopment

### Note

The University of California holds the copyright on all BOINC source code. By 
submitting contributions to the BOINC code, you irrevocably assign all right, 
title, and interest, including copyright and all copyright rights, in such 
contributions to The Regents of the University of California, who may then 
use the code for any purpose that it desires. 

# License
BOINC is free software; you can redistribute it and/or modify it
under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation,
either version 3 of the License, or (at your option) any later version.

BOINC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with BOINC.  If not, see <http://www.gnu.org/licenses/>.

==> boinc_7.9.3+dfsg.orig.tar.gz: boinc-client_release-7.10-7.9.3/README.md <==
# Status

[![Build Status](https://travis-ci.org/BOINC/boinc.svg?branch=master)](https://travis-ci.org/BOINC/boinc) [![Build status](https://ci.appveyor.com/api/projects/status/9dgoc9h5ppos8vcy/branch/master?svg=true)](https://ci.appveyor.com/project/BOINC/boinc/branch/master) [![Coverity Scan Build Status](https://scan.coverity.com/projects/4226/badge.svg)](https://scan.coverity.com/projects/boinc-boinc) [![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/BOINC/boinc/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/BOINC/boinc/?branch=master)

# BOINC

Project Website: https://boinc.berkeley.edu

## Want to create a project
See: https://boinc.berkeley.edu/trac/wiki

## Want to help translate
See: https://boinc.berkeley.edu/trac/wiki/TranslateIntro

## Want to contribute
See: https://boinc.berkeley.edu/trac/wiki/SoftwareDevelopment

### Note

The University of California holds the copyright on all BOINC source code. By 
submitting contributions to the BOINC code, you irrevocably assign all right, 
title, and interest, including copyright and all copyright rights, in such 
contributions to The Regents of the University of California, who may then 
use the code for any purpose that it desires. 

# License
BOINC is free software; you can redistribute it and/or modify it
under the terms of the GNU Lesser General Public License
as published by the Free Software Foundation,
either version 3 of the License, or (at your option) any later version.

BOINC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public License
along with BOINC.  If not, see <https://www.gnu.org/licenses/>.
